package cz.muni.fi.pb162.project.geometry;

/**
 *
 * @author Vitalii Bortsov
 */

public class Triangle {
    private Vertex2D[] arrayOfVertices = new Vertex2D[3];
    private Triangle[] arrayOfTriangles = {null, null, null};

    /**
     *
     * @param v1 1st vertex in new triangle
     * @param v2 2nd vertex in new triangle
     * @param v3 3rd vertex in new triangle
     */
    public Triangle(Vertex2D v1, Vertex2D v2, Vertex2D v3) {
        arrayOfVertices = new Vertex2D[] {v1, v2, v3};
    }

    /**
     *
     * @param index of Vertex in range 0 - 2
     * @return Vertex on input index
     */

    public Vertex2D getVertex(int index) {
        if(index > 2 || index < 0) {
            return null;
        }
        return arrayOfVertices[index];
    }

    /**
     *
     * @param index is index of Vertex you want to be changed. Must be in range 0 - 2
     * @param vertex is new Vertex you want to set.
     */

    public void setVertex(int index, Vertex2D vertex) {
        if(index > 2 || index < 0) {
            return;
        }
        arrayOfVertices[index] = vertex;
    }

    /**
     *
     * @return string with info about vertices in triangle
     */
    public String toString() {
        String v1 = arrayOfVertices[0].toString() + " ";
        String v2 = arrayOfVertices[1].toString() + " ";
        String v3 = arrayOfVertices[2].toString();
        return "Triangle: vertices=" + v1 + v2 + v3;
    }

    /**
     *
     * @return true if triangle has been already divided
     */
    public boolean isDivided() {
        return arrayOfTriangles[0] != null;
    }

    /**
     * divide the triangle if it is not divided
     * @return true if triangle is not divided
     */
    public boolean divide() {
        if(this.isDivided()) {
            return false;
        }
        for(int index = 0; index < 3; index++) {
            Vertex2D point1 = arrayOfVertices[index];
            Vertex2D point2 = arrayOfVertices[index].createMiddle(arrayOfVertices[(index + 1) % 3]);
            Vertex2D point3 = arrayOfVertices[index].createMiddle(arrayOfVertices[(index + 2) % 3]);
            Triangle triangle = new Triangle(point1, point2, point3);
            arrayOfTriangles[index] = triangle;
        }
        return true;
    }

    /**
     *
     * @param index must be in range 0-2
     * @return subtriangle on the position <index>
     */
    public Triangle getSubTriangle(int index) {
        if(!this.isDivided()){
            return null;
        }
        if(index > 2 || index < 0) {
            return null;
        }
        return arrayOfTriangles[index];
    }



}
